define(
//begin v1.x content
({
	fontSize: "Μέγεθος",
	fontName: "Γραμματοσειρά",
	formatBlock: "Μορφή",

	serif: "με πατούρες (serif)",
	"sans-serif": "χωρίς πατούρες (sans-serif)",
	monospace: "σταθερού πλάτους",
	cursive: "πλάγιοι",
	fantasy: "φαντασίας",

	noFormat: "Χωρίς",
	p: "Παράγραφος",
	h1: "Επικεφαλίδα",
	h2: "Δευτερεύουσα επικεφαλίδα",
	h3: "Δευτερεύουσα επικεφαλίδα τρίτου επιπέδου",
	pre: "Προ-μορφοποιημένο",

	1: "xx-μικρά",
	2: "x-μικρά",
	3: "μικρά",
	4: "μεσαία",
	5: "μεγάλα",
	6: "x-μεγάλα",
	7: "xx-μεγάλα"
})
//end v1.x content
);
